@@ -77,7 +77,7 @@ class CampaignConfig(BaseModel):
     channel_id: UUID
     channel_type: ChannelType
     campaign_goal: Optional[CampaignGoal]
-    feed_id: str
+    feed_id: UUID
     selection_criteria: Optional[dict]
 
     @classmethod
