@@ -22,10 +22,6 @@ class DB(metaclass=SingletonMeta):
         self.sqlite_url = f"postgresql://{username}:{password}@{host}:{port}/{db}"
 
         self.engine = create_engine(self.sqlite_url)
-        self.create_db_and_tables()
-
-    def create_db_and_tables(self):
-        SQLModel.metadata.create_all(self.engine)
 
     def get_session(self):
         with Session(self.engine) as session:
