@@ -14,9 +14,10 @@ from ..integrations.dataclasses import LinkInfo
 from ..util.enum import to_enum
 from ..vacancies.models import Feed as FeedModel, Vacancy as VacancyModel, SalaryFrequency, RemoteType
 from ..util.vacancy import generate_vacancy_hash
+from ..services.clients import MSClient
 
 class VacancyLocation(BaseModel):
-    zip_code: str | None = None
+    zipcode: str | None = None
     city: str | None = None
     address: str | None = None
     state: str | None = None
@@ -96,7 +97,7 @@ class VacancyData(BaseModel):
             hours_min=self.hours.min,
             hours_max=self.hours.max,
             location_address=self.location.address,
-            location_zipcode=self.location.zip_code,
+            location_zipcode=self.location.zipcode,
             location_city=self.location.city,
             location_state=self.location.state,
             location_country=self.location.country,
@@ -135,7 +136,7 @@ class Vacancy(VacancyData):
 
         location = VacancyLocation(
             address=getattr(model, "location_address", None),
-            zip_code=getattr(model, "location_zipcode", None),
+            zipcode=getattr(model, "location_zipcode", None),
             city=getattr(model, "location_city", None),
             state=getattr(model, "location_state", None),
             country=getattr(model, "location_country", None),
